# letra
Label management utility for GitHub issues

Early, pre-Alpha, non-functional (yet)

[![License Badge][license-badge]][license-url] 

[![Linux CI Badge][linux-ci-badge]][linux-ci-url]
[![Mac CI Badge][mac-ci-badge]][mac-ci-url]
[![Windows CI Badge][windows-ci-badge]][windows-ci-url]  

[![Test Results Badge][tests-badge]][tests-url]
[![Coverage Badge][coverage-badge]][coverage-url]
[![Code Style Badge][black-badge]][black]


[version-badge]: https://img.shields.io/pypi/v/letra.svg?style=flat-square
[license-url]: ./LICENSE
[license-badge]: https://img.shields.io/github/license/swellaby/letra.svg?style=flat-square&color=blue
[downloads-badge]: https://img.shields.io/pypi/dm/letra.svg?style=flat-square
[linux-ci-badge]: https://img.shields.io/azure-devops/build/swellaby/opensource/49/master.svg?label=linux%20build&style=flat-square
[linux-ci-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=49
[mac-ci-badge]: https://img.shields.io/azure-devops/build/swellaby/opensource/90/master.svg?label=mac%20build&style=flat-square
[mac-ci-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=90
[windows-ci-badge]: https://img.shields.io/azure-devops/build/swellaby/opensource/56/master.svg?label=windows%20build&style=flat-square
[windows-ci-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=91
[coverage-badge]: https://img.shields.io/azure-devops/coverage/swellaby/opensource/91/master.svg?style=flat-square
[coverage-url]: https://codecov.io/gh/swellaby/letra
[tests-badge]: https://img.shields.io/azure-devops/tests/swellaby/opensource/91/master.svg?label=unit%20tests&style=flat-square
[tests-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=91&view=ms.vss-test-web.build-test-results-tab
[black-badge]: https://img.shields.io/badge/code%20style-black-black.svg?style=flat-square
[black]: https://black.readthedocs.io/en/stable/
[contributing]: .github/CONTRIBUTING.md
